<?php
	/*
		Plugin Name: WooCommerce ComNpay Payment Gateway
		Plugin URI: https://docs.comnpay.com
		Description: Add ComNpay Payment Gateway for WooCommerce.
		Version: 1.1.0
		Author: ComNpay
		Author URI: https://www.comnpay.com
		License: AFONE
	*/
	
	//Additional links on the plugin page

	add_filter( 'plugin_row_meta', 'comnpay_register_plugin_links', 10, 2 );

	function comnpay_register_plugin_links($links, $file) {
		$base = plugin_basename(__FILE__);
		if($file == $base) {
			$links[] = '<a href="https://www.comnpay.com" target="_blank">' . __( 'ComNpay', 'rsb' ) . '</a>';
			$links[] = '<a href="https://docs.comnpay.com" target="_blank">' . __( 'Documentation', 'rsb' ) . '</a>';
		}
		return $links;
	}

	/* WooCommerce fallback notice. */

	function woocommerce_cpg_fallback_notice() {
		$htmlToReturn = '<div class="error">';
		$htmlToReturn .= '<p>' . sprintf( __( 'WooCommerce ComNpay dépend de la dernière version de %s pour fonctionner !', 'comnpay' ), '<a href="http://wordpress.org/extend/plugins/woocommerce/">WooCommerce</a>' ) . '</p>';
		$htmlToReturn .= '</div>';
		echo $htmlToReturn;
	}

	/* Load functions. */

	function custom_payment_gateway_load() {
		if (!class_exists('WC_Payment_Gateway'))	{
			add_action( 'admin_notices', 'woocommerce_cpg_fallback_notice' );
			return;
		}
		function wc_Custom_add_gateway( $methods ) {
			$methods[] = 'WC_ComNpay';
			return $methods;
		}
		add_filter( 'woocommerce_payment_gateways', 'wc_Custom_add_gateway' );
		// Include the WooCommerce Custom Payment Gateways classes.
		require_once plugin_dir_path( __FILE__ ) . 'class-wc-comnpay.php';
	}

	add_action( 'plugins_loaded', 'custom_payment_gateway_load', 0 );

	/* Adds custom settings url in plugins page. */

	function comnpay_action_links( $links ) {
		$settings = array(
			'settings' => sprintf(
				'<a href="%s">%s</a>',
				admin_url( 'admin.php?page=wc-settings&tab=checkout' ),
				__( 'Payment Gateways', 'ComNpay')
			)
		);
		return array_merge( $settings, $links );
	}

	add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'comnpay_action_links' );
	
?>